@@ -13,13 +13,11 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-import click
-from lmanage import get_content_with_views
-from lmanage import provision_instance_permission_structure
 import coloredlogs
 import logging
-from lmanage.utils import create_df
+import click
+from lmanage.mapview import get_content_with_views
+from lmanage.configurator import provision_instance_permission_structure
 
 logger = logging.getLogger(__name__)
 
@@ -80,7 +78,7 @@ def configurator(**kwargs):
 
 # @instance_config.command()
 # @click.option("-t", "--test")
-# def update_configs(**kwargs):
+# .configurator.configura.configuratortor def update_configs(**kwargs):
 #     print(kwargs.items())
 
 
